@@ -1,6 +1,9 @@
 import functools
 import importlib
+import json
 import os
+import re
+import shutil
 import sys
 import traceback
 from pkgutil import walk_packages
@@ -10,21 +13,15 @@ from typing import Any
 from alive_progress import alive_bar
 from colorama import Fore, Style
 
+import prowler
 from prowler.config.config import orange_color
 from prowler.lib.check.compliance_models import load_compliance_framework
+from prowler.lib.check.custom_checks_metadata import update_check_metadata
 from prowler.lib.check.models import Check, load_check_metadata
 from prowler.lib.logger import logger
-
-try:
-    lib = os.environ["PROWLER_REPORT_LIB_PATH"]
-    outputs_module = importlib.import_module(lib)
-    report = getattr(outputs_module, "report")
-except KeyError:
-    from prowler.lib.outputs.outputs import report
-except Exception:
-    sys.exit(1)
-
+from prowler.lib.outputs.outputs import report
 from prowler.lib.utils.utils import open_file, parse_json_file
+from prowler.providers.aws.lib.allowlist.allowlist import allowlist_findings
 from prowler.providers.common.models import Audit_Metadata
 from prowler.providers.common.outputs import Provider_Output_Options
 
@@ -70,9 +67,9 @@ def bulk_load_compliance_frameworks(provider: str) -> dict:
                         # cis_v1.4_aws.json --> cis_v1.4_aws
                         compliance_framework_name = filename.split(".json")[0]
                         # Store the compliance info
-                        bulk_compliance_frameworks[
-                            compliance_framework_name
-                        ] = load_compliance_framework(file_path)
+                        bulk_compliance_frameworks[compliance_framework_name] = (
+                            load_compliance_framework(file_path)
+                        )
     except Exception as e:
         logger.error(f"{e.__class__.__name__}[{e.__traceback__.tb_lineno}] -- {e}")
 
@@ -90,6 +87,9 @@ def exclude_checks_to_run(checks_to_execute: set, excluded_checks: list) -> set:
 def exclude_services_to_run(
     checks_to_execute: set, excluded_services: list, provider: str
 ) -> set:
+    excluded_services = [
+        "awslambda" if service == "lambda" else service for service in excluded_services
+    ]
     # Recover checks from the input services
     for service in excluded_services:
         modules = recover_checks_from_provider(provider, service)
@@ -107,14 +107,86 @@ def exclude_services_to_run(
 
 # Load checks from checklist.json
 def parse_checks_from_file(input_file: str, provider: str) -> set:
-    checks_to_execute = set()
-    f = open_file(input_file)
-    json_file = parse_json_file(f)
+    """parse_checks_from_file returns a set of checks read from the given file"""
+    try:
+        checks_to_execute = set()
+        with open_file(input_file) as f:
+            json_file = parse_json_file(f)
 
-    for check_name in json_file[provider]:
-        checks_to_execute.add(check_name)
+        for check_name in json_file[provider]:
+            checks_to_execute.add(check_name)
 
-    return checks_to_execute
+        return checks_to_execute
+    except Exception as error:
+        logger.error(
+            f"{error.__class__.__name__}[{error.__traceback__.tb_lineno}] -- {error}"
+        )
+
+
+# Load checks from custom folder
+def parse_checks_from_folder(audit_info, input_folder: str, provider: str) -> int:
+    try:
+        imported_checks = 0
+        # Check if input folder is a S3 URI
+        if provider == "aws" and re.search(
+            "^s3://([^/]+)/(.*?([^/]+))/$", input_folder
+        ):
+            bucket = input_folder.split("/")[2]
+            key = ("/").join(input_folder.split("/")[3:])
+            s3_resource = audit_info.audit_session.resource("s3")
+            bucket = s3_resource.Bucket(bucket)
+            for obj in bucket.objects.filter(Prefix=key):
+                if not os.path.exists(os.path.dirname(obj.key)):
+                    os.makedirs(os.path.dirname(obj.key))
+                if obj.key[-1] == "/":
+                    continue
+                bucket.download_file(obj.key, obj.key)
+            input_folder = key
+        # Import custom checks by moving the checks folders to the corresponding services
+        with os.scandir(input_folder) as checks:
+            for check in checks:
+                if check.is_dir():
+                    check_module = input_folder + "/" + check.name
+                    # Copy checks to specific provider/service folder
+                    check_service = check.name.split("_")[0]
+                    prowler_dir = prowler.__path__
+                    prowler_module = f"{prowler_dir[0]}/providers/{provider}/services/{check_service}/{check.name}"
+                    if os.path.exists(prowler_module):
+                        shutil.rmtree(prowler_module)
+                    shutil.copytree(check_module, prowler_module)
+                    imported_checks += 1
+        return imported_checks
+    except Exception as error:
+        logger.critical(
+            f"{error.__class__.__name__}[{error.__traceback__.tb_lineno}] -- {error}"
+        )
+        sys.exit(1)
+
+
+# Load checks from custom folder
+def remove_custom_checks_module(input_folder: str, provider: str):
+    # Check if input folder is a S3 URI
+    s3_uri = False
+    if provider == "aws" and re.search("^s3://([^/]+)/(.*?([^/]+))/$", input_folder):
+        input_folder = ("/").join(input_folder.split("/")[3:])
+        s3_uri = True
+
+    with os.scandir(input_folder) as checks:
+        for check in checks:
+            if check.is_dir():
+                # Remove imported checks
+                check_service = check.name.split("_")[0]
+                prowler_dir = prowler.__path__
+                prowler_module = f"{prowler_dir[0]}/providers/{provider}/services/{check_service}/{check.name}"
+                if os.path.exists(prowler_module):
+                    shutil.rmtree(prowler_module)
+                # test if the service only had the loaded custom checks to delete the folder
+                prowler_service_module = prowler_module.rsplit("/", 1)[0]
+                if not os.listdir(prowler_service_module):
+                    shutil.rmtree(prowler_service_module)
+                # If S3 URI, remove the downloaded folders
+                if s3_uri and os.path.exists(input_folder):
+                    shutil.rmtree(input_folder)
 
 
 def list_services(provider: str) -> set():
@@ -122,57 +194,62 @@ def list_services(provider: str) -> set():
     checks_tuple = recover_checks_from_provider(provider)
     for _, check_path in checks_tuple:
         # Format: /absolute_path/prowler/providers/{provider}/services/{service_name}/{check_name}
-        service_name = check_path.split("/")[-2]
+        if os.name == "nt":
+            service_name = check_path.split("\\")[-2]
+        else:
+            service_name = check_path.split("/")[-2]
         available_services.add(service_name)
     return sorted(available_services)
 
 
-def list_categories(provider: str, bulk_checks_metadata: dict) -> set():
+def list_categories(bulk_checks_metadata: dict) -> set():
     available_categories = set()
     for check in bulk_checks_metadata.values():
         for cat in check.Categories:
-            available_categories.add(cat)
+            if cat:
+                available_categories.add(cat)
     return available_categories
 
 
 def print_categories(categories: set):
     categories_num = len(categories)
-    plural_string = f"There are {Fore.YELLOW}{categories_num}{Style.RESET_ALL} available categories: \n"
-    singular_string = f"There is {Fore.YELLOW}{categories_num}{Style.RESET_ALL} available category: \n"
+    plural_string = f"\nThere are {Fore.YELLOW}{categories_num}{Style.RESET_ALL} available categories.\n"
+    singular_string = f"\nThere is {Fore.YELLOW}{categories_num}{Style.RESET_ALL} available category.\n"
 
     message = plural_string if categories_num > 1 else singular_string
-    print(message)
-    for category in categories:
+    for category in sorted(categories):
         print(f"- {category}")
 
+    print(message)
+
 
 def print_services(service_list: set):
     services_num = len(service_list)
-    plural_string = (
-        f"There are {Fore.YELLOW}{services_num}{Style.RESET_ALL} available services: \n"
-    )
+    plural_string = f"\nThere are {Fore.YELLOW}{services_num}{Style.RESET_ALL} available services.\n"
     singular_string = (
-        f"There is {Fore.YELLOW}{services_num}{Style.RESET_ALL} available service: \n"
+        f"\nThere is {Fore.YELLOW}{services_num}{Style.RESET_ALL} available service.\n"
     )
 
     message = plural_string if services_num > 1 else singular_string
-    print(message)
 
     for service in service_list:
         print(f"- {service}")
 
+    print(message)
+
 
 def print_compliance_frameworks(
     bulk_compliance_frameworks: dict,
 ):
     frameworks_num = len(bulk_compliance_frameworks.keys())
-    plural_string = f"There are {Fore.YELLOW}{frameworks_num}{Style.RESET_ALL} available Compliance Frameworks: \n"
-    singular_string = f"There is {Fore.YELLOW}{frameworks_num}{Style.RESET_ALL} available Compliance Framework: \n"
+    plural_string = f"\nThere are {Fore.YELLOW}{frameworks_num}{Style.RESET_ALL} available Compliance Frameworks.\n"
+    singular_string = f"\nThere is {Fore.YELLOW}{frameworks_num}{Style.RESET_ALL} available Compliance Framework.\n"
     message = plural_string if frameworks_num > 1 else singular_string
 
+    for framework in sorted(bulk_compliance_frameworks.keys()):
+        print(f"- {framework}")
+
     print(message)
-    for framework in bulk_compliance_frameworks.keys():
-        print(f"\t- {Fore.YELLOW}{framework}{Style.RESET_ALL}")
 
 
 def print_compliance_requirements(
@@ -199,6 +276,15 @@ def print_compliance_requirements(
                     )
 
 
+def list_checks_json(provider: str, check_list: set):
+    try:
+        output = {provider: check_list}
+        return json.dumps(output, indent=2, default=str)
+    except Exception as e:
+        logger.critical(f"{e.__class__.__name__}[{e.__traceback__.tb_lineno}]: {e}")
+        sys.exit(1)
+
+
 def print_checks(
     provider: str,
     check_list: set,
@@ -210,10 +296,9 @@ def print_checks(
                 f"[{bulk_checks_metadata[check].CheckID}] {bulk_checks_metadata[check].CheckTitle} - {Fore.MAGENTA}{bulk_checks_metadata[check].ServiceName} {Fore.YELLOW}[{bulk_checks_metadata[check].Severity}]{Style.RESET_ALL}"
             )
         except KeyError as error:
-            logger.critical(
+            logger.error(
                 f"Check {error} was not found for the {provider.upper()} provider"
             )
-            sys.exit(1)
 
     checks_num = len(check_list)
     plural_string = (
@@ -231,7 +316,7 @@ def print_checks(
 def parse_checks_from_compliance_framework(
     compliance_frameworks: list, bulk_compliance_frameworks: dict
 ) -> list:
-    """Parse checks from compliance frameworks specification"""
+    """parse_checks_from_compliance_framework returns a set of checks from the given compliance_frameworks"""
     checks_to_execute = set()
     try:
         for framework in compliance_frameworks:
@@ -286,7 +371,7 @@ def list_compliance_modules():
     """
     list_compliance_modules returns the available compliance frameworks and returns their path
     """
-    # This module path requires the full path includig "prowler."
+    # This module path requires the full path including "prowler."
     module_path = "prowler.compliance"
     return walk_packages(
         importlib.import_module(module_path).__path__,
@@ -296,7 +381,7 @@ def list_compliance_modules():
 
 # List all available modules in the selected provider and service
 def list_modules(provider: str, service: str):
-    # This module path requires the full path includig "prowler."
+    # This module path requires the full path including "prowler."
     module_path = f"prowler.providers.{provider}.services"
     if service:
         module_path += f".{service}"
@@ -338,6 +423,7 @@ def execute_checks(
     provider: str,
     audit_info: Any,
     audit_output_options: Provider_Output_Options,
+    custom_checks_metadata: Any,
 ) -> list:
     # List to store all the check's findings
     all_findings = []
@@ -353,6 +439,22 @@ def execute_checks(
         audit_progress=0,
     )
 
+    if os.name != "nt":
+        try:
+            from resource import RLIMIT_NOFILE, getrlimit
+
+            # Check ulimit for the maximum system open files
+            soft, _ = getrlimit(RLIMIT_NOFILE)
+            if soft < 4096:
+                logger.warning(
+                    f"Your session file descriptors limit ({soft} open files) is below 4096. We recommend to increase it to avoid errors. Solve it running this command `ulimit -n 4096`. For more info visit https://docs.prowler.cloud/en/latest/troubleshooting/"
+                )
+        except Exception as error:
+            logger.error("Unable to retrieve ulimit default settings")
+            logger.error(
+                f"{error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
+            )
+
     # Execution with the --only-logs flag
     if audit_output_options.only_logs:
         for check_name in checks_to_execute:
@@ -367,15 +469,15 @@ def execute_checks(
                     audit_info,
                     services_executed,
                     checks_executed,
+                    custom_checks_metadata,
                 )
                 all_findings.extend(check_findings)
 
             # If check does not exists in the provider or is from another provider
             except ModuleNotFoundError:
-                logger.critical(
+                logger.error(
                     f"Check '{check_name}' was not found for the {provider.upper()} provider"
                 )
-                sys.exit(1)
             except Exception as error:
                 logger.error(
                     f"{check_name} - {error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
@@ -413,21 +515,20 @@ def execute_checks(
                         audit_info,
                         services_executed,
                         checks_executed,
+                        custom_checks_metadata,
                     )
                     all_findings.extend(check_findings)
-                    bar()
 
                 # If check does not exists in the provider or is from another provider
                 except ModuleNotFoundError:
-                    logger.critical(
+                    logger.error(
                         f"Check '{check_name}' was not found for the {provider.upper()} provider"
                     )
-                    bar.title = f"-> {Fore.RED}Scan was aborted!{Style.RESET_ALL}"
-                    sys.exit(1)
                 except Exception as error:
                     logger.error(
                         f"{check_name} - {error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
                     )
+                bar()
             bar.title = f"-> {Fore.GREEN}Scan completed!{Style.RESET_ALL}"
     return all_findings
 
@@ -440,6 +541,7 @@ def execute(
     audit_info: Any,
     services_executed: set,
     checks_executed: set,
+    custom_checks_metadata: Any,
 ):
     # Import check module
     check_module_path = (
@@ -450,6 +552,10 @@ def execute(
     check_to_execute = getattr(lib, check_name)
     c = check_to_execute()
 
+    # Update check metadata to reflect that in the outputs
+    if custom_checks_metadata and custom_checks_metadata["Checks"].get(c.CheckID):
+        c = update_check_metadata(c, custom_checks_metadata["Checks"][c.CheckID])
+
     # Run check
     check_findings = run_check(c, audit_output_options)
 
@@ -460,9 +566,28 @@ def execute(
         audit_info.audit_metadata, services_executed, checks_executed
     )
 
+    # Allowlist findings
+    if audit_output_options.allowlist_file:
+        check_findings = allowlist_findings(
+            audit_output_options.allowlist_file,
+            audit_info.audited_account,
+            check_findings,
+        )
+
     # Report the check's findings
     report(check_findings, audit_output_options, audit_info)
 
+    if os.environ.get("PROWLER_REPORT_LIB_PATH"):
+        try:
+            logger.info("Using custom report interface ...")
+            lib = os.environ["PROWLER_REPORT_LIB_PATH"]
+            outputs_module = importlib.import_module(lib)
+            custom_report_interface = getattr(outputs_module, "report")
+
+            custom_report_interface(check_findings, audit_output_options, audit_info)
+        except Exception:
+            sys.exit(1)
+
     return check_findings
 
 
@@ -488,84 +613,32 @@ def update_audit_metadata(
         )
 
 
-def recover_checks_from_service(service_list: list, provider: str) -> list:
-    checks = set()
-    for service in service_list:
-        modules = recover_checks_from_provider(provider, service)
-        if not modules:
-            logger.error(f"Service '{service}' does not have checks.")
+def recover_checks_from_service(service_list: list, provider: str) -> set:
+    """
+    Recover all checks from the selected provider and service
 
-        else:
-            for check_module in modules:
-                # Recover check name and module name from import path
-                # Format: "providers.{provider}.services.{service}.{check_name}.{check_name}"
-                check_name = check_module[0].split(".")[-1]
-                # If the service is present in the group list passed as parameters
-                # if service_name in group_list: checks_from_arn.add(check_name)
-                checks.add(check_name)
-    return checks
+    Returns a set of checks from the given services
+    """
+    try:
+        checks = set()
+        service_list = [
+            "awslambda" if service == "lambda" else service for service in service_list
+        ]
+        for service in service_list:
+            service_checks = recover_checks_from_provider(provider, service)
+            if not service_checks:
+                logger.error(f"Service '{service}' does not have checks.")
 
-
-def get_checks_from_input_arn(audit_resources: list, provider: str) -> set:
-    """get_checks_from_input_arn gets the list of checks from the input arns"""
-    checks_from_arn = set()
-    # Handle if there are audit resources so only their services are executed
-    if audit_resources:
-        services_without_subservices = ["guardduty", "kms", "s3", "elb"]
-        service_list = set()
-        sub_service_list = set()
-        for resource in audit_resources:
-            service = resource.split(":")[2]
-            sub_service = resource.split(":")[5].split("/")[0].replace("-", "_")
-
-            if (
-                service != "wafv2" and service != "waf"
-            ):  # WAF Services does not have checks
-                # Parse services when they are different in the ARNs
-                if service == "lambda":
-                    service = "awslambda"
-                if service == "elasticloadbalancing":
-                    service = "elb"
-                elif service == "logs":
-                    service = "cloudwatch"
-                service_list.add(service)
-
-                # Get subservices to execute only applicable checks
-                if service not in services_without_subservices:
-                    # Parse some specific subservices
-                    if service == "ec2":
-                        if sub_service == "security_group":
-                            sub_service = "securitygroup"
-                        if sub_service == "network_acl":
-                            sub_service = "networkacl"
-                        if sub_service == "image":
-                            sub_service = "ami"
-                    if service == "rds":
-                        if sub_service == "cluster_snapshot":
-                            sub_service = "snapshot"
-                    sub_service_list.add(sub_service)
-                else:
-                    sub_service_list.add(service)
-
-        checks = recover_checks_from_service(service_list, provider)
-
-        # Filter only checks with audited subservices
-        for check in checks:
-            if any(sub_service in check for sub_service in sub_service_list):
-                if not (sub_service == "policy" and "password_policy" in check):
-                    checks_from_arn.add(check)
-
-    # Return final checks list
-    return sorted(checks_from_arn)
-
-
-def get_regions_from_audit_resources(audit_resources: list) -> list:
-    """get_regions_from_audit_resources gets the regions from the audit resources arns"""
-    audited_regions = []
-    for resource in audit_resources:
-        region = resource.split(":")[3]
-        if region and region not in audited_regions:  # Check if arn has a region
-            audited_regions.append(region)
-    if audited_regions:
-        return audited_regions
-    return None
+            else:
+                for check in service_checks:
+                    # Recover check name and module name from import path
+                    # Format: "providers.{provider}.services.{service}.{check_name}.{check_name}"
+                    check_name = check[0].split(".")[-1]
+                    # If the service is present in the group list passed as parameters
+                    # if service_name in group_list: checks_from_arn.add(check_name)
+                    checks.add(check_name)
+        return checks
+    except Exception as error:
+        logger.error(
+            f"{error.__class__.__name__}[{error.__traceback__.tb_lineno}]: {error}"
+        )
