@@ -12,15 +12,16 @@ class cloudfront_distributions_field_level_encryption_enabled(Check):
             report.region = distribution.region
             report.resource_arn = distribution.arn
             report.resource_id = distribution.id
+            report.resource_tags = distribution.tags
             if (
                 distribution.default_cache_config
                 and distribution.default_cache_config.field_level_encryption_id
             ):
                 report.status = "PASS"
-                report.status_extended = f"CloudFront Distribution {distribution.id} has Field Level Encryption enabled"
+                report.status_extended = f"CloudFront Distribution {distribution.id} has Field Level Encryption enabled."
             else:
                 report.status = "FAIL"
-                report.status_extended = f"CloudFront Distribution {distribution.id} has Field Level Encryption disabled"
+                report.status_extended = f"CloudFront Distribution {distribution.id} has Field Level Encryption disabled."
 
             findings.append(report)
 
