@@ -15,12 +15,13 @@ class cloudfront_distributions_geo_restrictions_enabled(Check):
             report.region = distribution.region
             report.resource_arn = distribution.arn
             report.resource_id = distribution.id
+            report.resource_tags = distribution.tags
             if distribution.geo_restriction_type == GeoRestrictionType.none:
                 report.status = "FAIL"
-                report.status_extended = f"CloudFront Distribution {distribution.id} has Geo restrictions disabled"
+                report.status_extended = f"CloudFront Distribution {distribution.id} has Geo restrictions disabled."
             else:
                 report.status = "PASS"
-                report.status_extended = f"CloudFront Distribution {distribution.id} has Geo restrictions enabled"
+                report.status_extended = f"CloudFront Distribution {distribution.id} has Geo restrictions enabled."
 
             findings.append(report)
 
