@@ -15,15 +15,17 @@ class directoryservice_supported_mfa_radius_enabled(Check):
                 report = Check_Report_AWS(self.metadata())
                 report.region = directory.region
                 report.resource_id = directory.id
+                report.resource_arn = directory.arn
+                report.resource_tags = directory.tags
                 if directory.radius_settings.status == RadiusStatus.Completed:
                     report.status = "PASS"
                     report.status_extended = (
-                        f"Directory {directory.id} have Radius MFA enabled"
+                        f"Directory {directory.id} have Radius MFA enabled."
                     )
                 else:
                     report.status = "FAIL"
                     report.status_extended = (
-                        f"Directory {directory.id} does not have Radius MFA enabled"
+                        f"Directory {directory.id} does not have Radius MFA enabled."
                     )
 
                 findings.append(report)
