@@ -7,7 +7,8 @@ class iam_password_policy_lowercase(Check):
         findings = []
         report = Check_Report_AWS(self.metadata())
         report.region = iam_client.region
-        report.resource_id = "password_policy"
+        report.resource_arn = iam_client.password_policy_arn_template
+        report.resource_id = iam_client.audited_account
         # Check if password policy exists
         if iam_client.password_policy:
             # Check if lowercase flag is set
@@ -21,6 +22,6 @@ class iam_password_policy_lowercase(Check):
                 report.status_extended = "IAM password policy does not require at least one lowercase letter."
         else:
             report.status = "FAIL"
-            report.status_extended = "Password policy cannot be found"
+            report.status_extended = "Password policy cannot be found."
         findings.append(report)
         return findings
