@@ -9,6 +9,8 @@ class rds_instance_minor_version_upgrade_enabled(Check):
             report = Check_Report_AWS(self.metadata())
             report.region = db_instance.region
             report.resource_id = db_instance.id
+            report.resource_arn = db_instance.arn
+            report.resource_tags = db_instance.tags
             if db_instance.auto_minor_version_upgrade:
                 report.status = "PASS"
                 report.status_extended = (
