@@ -12,16 +12,16 @@ class route53_domains_transferlock_enabled(Check):
             report = Check_Report_AWS(self.metadata())
             report.resource_id = domain.name
             report.region = domain.region
-
+            report.resource_tags = domain.tags
             if domain.status_list and "clientTransferProhibited" in domain.status_list:
                 report.status = "PASS"
                 report.status_extended = (
-                    f"Transfer Lock is enabled for the {domain.name} domain"
+                    f"Transfer Lock is enabled for the {domain.name} domain."
                 )
             else:
                 report.status = "FAIL"
                 report.status_extended = (
-                    f"Transfer Lock is disabled for the {domain.name} domain"
+                    f"Transfer Lock is disabled for the {domain.name} domain."
                 )
 
             findings.append(report)
