@@ -10,11 +10,12 @@ class sagemaker_notebook_instance_encryption_enabled(Check):
             report.region = notebook_instance.region
             report.resource_id = notebook_instance.name
             report.resource_arn = notebook_instance.arn
+            report.resource_tags = notebook_instance.tags
             report.status = "PASS"
-            report.status_extended = f"Sagemaker notebook instance {notebook_instance.name} has data encryption enabled"
+            report.status_extended = f"Sagemaker notebook instance {notebook_instance.name} has data encryption enabled."
             if not notebook_instance.kms_key_id:
                 report.status = "FAIL"
-                report.status_extended = f"Sagemaker notebook instance {notebook_instance.name} has data encryption disabled"
+                report.status_extended = f"Sagemaker notebook instance {notebook_instance.name} has data encryption disabled."
 
             findings.append(report)
 
