@@ -9,18 +9,17 @@ class ssm_managed_compliant_patching(Check):
         for resource in ssm_client.compliance_resources.values():
             report = Check_Report_AWS(self.metadata())
             report.region = resource.region
-            report.resource_arn = f"arn:aws:ec2:{resource.region}:{ssm_client.audited_account}:instance/{resource.id}"
             report.resource_id = resource.id
 
             if resource.status == ResourceStatus.COMPLIANT:
                 report.status = "PASS"
                 report.status_extended = (
-                    f"EC2 managed instance {resource.id} is compliant"
+                    f"EC2 managed instance {resource.id} is compliant."
                 )
             else:
                 report.status = "FAIL"
                 report.status_extended = (
-                    f"EC2 managed instance {resource.id} is non-compliant"
+                    f"EC2 managed instance {resource.id} is non-compliant."
                 )
 
             findings.append(report)
