@@ -9,13 +9,13 @@ class storage_blob_public_access_level_is_disabled(Check):
             for storage_account in storage_accounts:
                 report = Check_Report_Azure(self.metadata())
                 report.subscription = subscription
-                report.status = "PASS"
-                report.status_extended = f"Storage account {storage_account.name} from subscription {subscription} has allow blob public access disabled"
+                report.status = "FAIL"
+                report.status_extended = f"Storage account {storage_account.name} from subscription {subscription} has allow blob public access enabled."
                 report.resource_name = storage_account.name
                 report.resource_id = storage_account.id
                 if not storage_account.allow_blob_public_access:
-                    report.status = "FAIL"
-                    report.status_extended = f"Storage account {storage_account.name} from subscription {subscription} has allow blob public access enabled"
+                    report.status = "PASS"
+                    report.status_extended = f"Storage account {storage_account.name} from subscription {subscription} has allow blob public access disabled."
 
                 findings.append(report)
 
